==> nw-gulp-tasks-0.6.0.tgz: package/tasks/release.js <==
'use strict';

var gulp = require('gulp');
var del = require('del');
var _ = require('lodash');
var argv = require('yargs').argv;
var path = require('path');
var $ = require('gulp-load-plugins')({
    config: path.normalize(__dirname + '/../package.json')
});

var config = {
    name: 'project'
};

function  release(options) {
    var settings = _.extend(config, options);

    var task = {
        desc: 'Create a new tag, rebase branches and push to repo',
        subtasks: [{
            name: 'bump',
            callback: bump
        },{
            name: 'rebase',
            callback: rebase
        },{
            name: 'tag',
            callback: tag
        }]
    };

    ////////////////

    function runner(done) {
        runSequence(
            'release:bump',
            'release:rebase',
            'release:tag',
            done
        );
    }

    function bump(done) {
        return gulp.src([
                './bower.json',
                './package.json'
            ])
            .pipe($.bump({version: argv.v}))
            .pipe(gulp.dest('./'))
            .pipe($.git.add())
            .pipe($.git.commit('[CHANGE] - Bump bower.json and package.json'))
            .pipe($.size({title: 'release:bump'}));
    }

    function rebase(done) {
        return gulp.src('./')
            .pipe($.shell('git checkout master'))
            .pipe($.shell('git merge develop'))
            .pipe($.shell('git checkout develop'))
            .pipe($.shell('git push origin --all'))
            .pipe($.size({title: 'release:rebase'}));
    }

    function tag(done) {
        return gulp.src('./')
            .pipe($.shell('git tag v' + argv.v))
            .pipe($.shell('git push origin --tags'))
            .pipe($.size({title: 'release:tag'}));
    }

    ////////////////

    return task;
}

module.exports = release;

==> nw-gulp-tasks-0.7.1.tgz: package/tasks/release.js <==
'use strict';

var gulp = require('gulp');
var _ = require('lodash');
var argv = require('yargs').argv;
var path = require('path');
var $ = require('gulp-load-plugins')({
    config: path.normalize(__dirname + '/../package.json')
});

var config = {
    name: 'project',
    bump: [
        'package.json',
        'bower.json'
    ]
};

function  release(options) {
    var settings = _.extend(config, options);
    var dependencies = ['build'];

    if (settings.scripts) {
        dependencies.push('scripts:analysis');
    }

    var task = {
        desc: 'Create a new tag, rebase branches and push to repo',
        dependencies: {
            exec: 'before',
            tasks: dependencies
        },
        subtasks: [{
            name: 'bump',
            callback: bump
        },{
            name: 'rebase',
            callback: rebase
        },{
            name: 'tag',
            callback: tag
        }]
    };

    ////////////////

    function bump() {
        return gulp.src(settings.bump)
            .pipe($.bump({version: argv.v}))
            .pipe(gulp.dest('./'))
            .pipe($.git.add())
            .pipe($.git.commit('[CHANGE] - Build project and bump bower.json and package.json'))
            .pipe($.size({title: 'release:bump'}));
    }

    function rebase() {
        return gulp.src('./')
            .pipe($.shell('git checkout master'))
            .pipe($.shell('git merge develop'))
            .pipe($.shell('git checkout develop'))
            .pipe($.shell('git push origin --all'))
            .pipe($.size({title: 'release:rebase'}));
    }

    function tag() {
        return gulp.src('./')
            .pipe($.shell('git tag v' + argv.v))
            .pipe($.shell('git push origin --tags'))
            .pipe($.size({title: 'release:tag'}));
    }

    ////////////////

    return task;
}

module.exports = release;
